@@ -87,6 +87,7 @@ class PlayerManager(object):
         self._tl_lock = RLock()
         self.last_update = Timer()
         self._jf_settings = None
+        self.get_webview = lambda: None
 
         if is_using_ext_mpv:
             extra_options = {
@@ -260,6 +261,10 @@ class PlayerManager(object):
 
         if settings.log_decisions:
             log.debug("Playing: {0}".format(url))
+        if (self.get_webview() is not None and
+            (settings.display_mirroring or settings.desktop_fullscreen)):
+            self.get_webview().hide()
+
         self._player.play(self.url)
         self._player.wait_for_property("duration")
         if settings.fullscreen:
@@ -274,8 +279,6 @@ class PlayerManager(object):
         self.update_subtitle_visuals()
 
         if win_utils:
-            if settings.display_mirroring:
-                win_utils.mirror_act(False)
             win_utils.raise_mpv()
 
         if offset is not None and offset > 0:
@@ -524,8 +527,9 @@ class PlayerManager(object):
         self.should_send_timeline = False
         self._video.client.jellyfin.session_stop(self.get_timeline_options())
         
-        if win_utils and settings.display_mirroring:
-            win_utils.mirror_act(True)
+        if (self.get_webview() is not None and
+            (settings.display_mirroring or settings.desktop_fullscreen)):
+            self.get_webview().show()
 
     def upd_player_hide(self):
         self._player.keep_open = self._video.parent.has_next
